@@ -8,15 +8,9 @@ def main(): ...
 
 
 @main.command()
-def hello():
-    text = pymeet.hello()
-    click.echo(text)
-
-
-@main.command()
-def world():
-    text = pymeet.world()
-    click.echo(text)
+def start():
+    app = pymeet.PyMeet((1080, 720), 30)
+    app.start()
 
 
 @main.command()
@@ -27,8 +21,7 @@ def echo(text, option):
     click.echo(text + option_text)
 
 
-main.add_command(hello, 'hello')
-main.add_command(world, 'world')
+main.add_command(start, 'start')
 main.add_command(echo, 'echo')
 
 
